@@ -17,23 +17,24 @@ This example uses the :ref:`django pulse <apps-pulse>` application.
 Views and Middleware
 ==========================
 
-Check the :mod:`examples.djangoapp.chat.settings` module to see how this classes
-are used.
+Check the :mod:`examples.djangoapp.chat.settings` module to see how this
+classes are used.
 
 .. automodule:: examples.djangoapp.chat.views
    :members:
    :member-order: bysource
-   
+
 '''
-import os, sys
+import os
 try:
     import pulsar
-except ImportError: #pragma nocover
+except ImportError:     # pragma nocover
     import sys
     sys.path.append('../../')
-    
+
 os.environ["DJANGO_SETTINGS_MODULE"] = "chat.settings"
 from django.core.management import execute_from_command_line
-    
+
+
 if __name__ == "__main__":
-    execute_from_command_line()
\ No newline at end of file
+    execute_from_command_line()
