@@ -1,21 +1,22 @@
-'''Tests the "helloworld" example.'''
-from pulsar import send, SERVER_SOFTWARE, get_application
+'''Tests the "helloworld" example.
+'''
+from pulsar import send, SERVER_SOFTWARE, get_application, get_actor
 from pulsar import MultiDeferred
 from pulsar.utils.pep import range
 from pulsar.apps.http import HttpClient
 from pulsar.apps.test import unittest, run_on_arbiter, dont_run_with_thread
 
 from .manage import server
-        
+
 
 class TestHelloWorldThread(unittest.TestCase):
     app = None
     concurrency = 'thread'
-    
+
     @classmethod
     def name(cls):
         return 'helloworld_' + cls.concurrency
-    
+
     @classmethod
     def setUpClass(cls):
         s = server(name=cls.name(), concurrency=cls.concurrency,
@@ -23,21 +24,22 @@ class TestHelloWorldThread(unittest.TestCase):
         cls.app = yield send('arbiter', 'run', s)
         cls.uri = 'http://{0}:{1}'.format(*cls.app.address)
         cls.client = HttpClient()
-        
+
     @classmethod
     def tearDownClass(cls):
         if cls.app is not None:
             yield send('arbiter', 'kill_actor', cls.app.name)
-    
+
     @run_on_arbiter
     def testMeta(self):
         app = yield get_application(self.name())
         self.assertEqual(app.name, self.name())
-        self.assertTrue(app.monitor.is_running())
-        self.assertEqual(app, app.app)
+        monitor = get_actor().get_actor(app.name)
+        self.assertTrue(monitor.is_running())
+        self.assertEqual(app, monitor.app)
         self.assertEqual(str(app), app.name)
         self.assertEqual(app.cfg.bind, '127.0.0.1:0')
-        
+
     def testResponse(self):
         c = self.client
         response = yield c.get(self.uri).on_finished
@@ -48,7 +50,7 @@ class TestHelloWorldThread(unittest.TestCase):
         self.assertTrue(headers)
         self.assertEqual(headers['content-type'], 'text/plain')
         self.assertEqual(headers['server'], SERVER_SOFTWARE)
-    
+
     def testTimeIt(self):
         c = self.client
         response = c.timeit(5, 'get', self.uri)
@@ -58,7 +60,7 @@ class TestHelloWorldThread(unittest.TestCase):
         self.assertTrue(response.locked_time >= 0)
         self.assertTrue(response.total_time >= response.locked_time)
         self.assertEqual(response.num_failures, 0)
-        
+
     def test_getbench(self):
         c = self.client
         yield MultiDeferred((c.get(self.uri) for _ in range(1))).lock()
@@ -68,4 +70,3 @@ class TestHelloWorldThread(unittest.TestCase):
 @dont_run_with_thread
 class TestHelloWorldProcess(TestHelloWorldThread):
     concurrency = 'process'
-    
\ No newline at end of file
