@@ -1,7 +1,7 @@
 '''
-The `dining philosophers`_ problem is an example problem often used in concurrent
-algorithm design to illustrate synchronization issues and techniques
-for resolving them.
+The dining `philosophers`_ problem is an example problem often used in
+concurrent algorithm design to illustrate synchronisation issues and
+techniques for resolving them.
 
 The problem
 ===================
@@ -14,10 +14,10 @@ A fork ``f`` is placed between each pair of adjacent philosophers ``P``::
          O  f  O
         f       f
      P O         O P
-         f     f 
+         f     f
             O
             P
-           
+
 Each philosopher ``P`` must alternately think and eat from his bowl ``O``.
 Eating is not limited by the amount of spaghetti left: assume an infinite
 supply.
@@ -35,22 +35,23 @@ There are two parameters:
 * Average eating period, the higher the more time is spend eating.
 * Average waiting period, the higher the more frequent philosophers
   get a chance to eat.
-    
+
 To run the example, type::
 
     pulsar manage.py
-    
+
 Implementation
 =====================
 
 .. autoclass:: DiningPhilosophers
    :members:
    :member-order: bysource
-   
-.. _`dining philosophers`: http://en.wikipedia.org/wiki/Dining_philosophers_problem
+
+.. _`philosophers`: http://en.wikipedia.org/wiki/Dining_philosophers_problem
 '''
 import random
 import time
+from functools import partial
 try:
     import pulsar
 except ImportError:
@@ -58,23 +59,25 @@ except ImportError:
     sys.path.append('../../')
     import pulsar
 from pulsar import command
-    
-################################################################################
+
+
+###########################################################################
 ##    EXTRA COMMAND LINE PARAMETERS
 class Eating_Period(pulsar.Setting):
     flags = ["--eating-period"]
     validator = pulsar.validate_pos_float
     default = 2
     desc = """The average period of eating for a philosopher."""
-    
-    
+
+
 class Waiting_Period(pulsar.Setting):
     flags = ["--waiting-period"]
     validator = pulsar.validate_pos_float
     default = 2
     desc = """The average period of waiting for a missing fork."""
-    
-################################################################################
+
+
+###########################################################################
 ##    PULSAR COMMANDS FOR DINING PHILOSOPHERS
 @command(ack=False)
 def putdown_fork(request, fork):
@@ -82,7 +85,8 @@ def putdown_fork(request, fork):
     try:
         self.not_available_forks.remove(fork)
     except KeyError:
-        self.logger.error('Putting down a fork which was already available')    
+        self.logger.error('Putting down a fork which was already available')
+
 
 @command()
 def pickup_fork(request, fork_right):
@@ -90,7 +94,7 @@ def pickup_fork(request, fork_right):
     num_philosophers = self.cfg.workers
     fork_left = fork_right - 1
     if fork_left == 0:
-        fork_left = num_philosophers 
+        fork_left = num_philosophers
     for fork in (fork_right, fork_left):
         if fork not in self.not_available_forks:
             # Fork is available, send it to the philosopher
@@ -98,27 +102,26 @@ def pickup_fork(request, fork_right):
             return fork
 
 
-################################################################################
+############################################################################
 ##    DINING PHILOSOPHERS APP
 class DiningPhilosophers(pulsar.Application):
-    description = 'Dining philosophers sit at a table around a bowl of '\
-                  'spaghetti and waits for available forks.'
+    description = ('Dining philosophers sit at a table around a bowl of '
+                   'spaghetti and waits for available forks.')
     cfg = pulsar.Config(workers=5)
-    
+
     def monitor_start(self, monitor):
         self.not_available_forks = set()
-        
+
     def worker_start(self, philosopher):
         self.take_action(philosopher)
-        
-    def worker_info(self, philosopher, info):
+
+    def worker_info(self, philosopher, info=None):
         '''Override :meth:`pulsar.Application.worker_info` to provide
 information about the philosopher.'''
         params = philosopher.params
         info['philosopher'] = {'number': params.number,
                                'eaten': params.eaten}
-        return info
-    
+
     def take_action(self, philosopher):
         '''The ``philosopher`` performs one of these two actions:
 
@@ -165,14 +168,15 @@ information about the philosopher.'''
             self.pickup_fork(philosopher)
         else:
             self.release_forks(philosopher)
-        
+
     def pickup_fork(self, philosopher):
         '''The philosopher has less than two forks. Check if forks are
 available.'''
         right_fork = philosopher.params.number
-        return philosopher.send(philosopher.monitor, 'pickup_fork', right_fork)\
-                          .add_callback_args(self._continue, philosopher)
-    
+        return philosopher.send(philosopher.monitor, 'pickup_fork', right_fork
+                                ).add_callback(partial(self._continue,
+                                                       philosopher))
+
     def release_forks(self, philosopher):
         '''The ``philosopher`` has just eaten and is ready to release both
 forks. This method release them, one by one, by sending the ``put_down``
@@ -186,17 +190,18 @@ action to the monitor.'''
         # once released all the forks wait for a moment
         time.sleep(self.cfg.waiting_period)
         self._continue(None, philosopher)
-    
-    def _continue(self, fork, philosopher):
+
+    def _continue(self, philosopher, fork):
         if fork:
             forks = philosopher.params.forks
             if fork in forks:
-                philosopher.logger.error('Got fork %s. I already have it', fork)
+                philosopher.logger.error('Got fork %s. I already have it',
+                                         fork)
             else:
                 philosopher.logger.debug('Got fork %s.', fork)
                 forks.append(fork)
         self.take_action(philosopher)
-    
+
     def actorparams(self, monitor, params):
         avail = set(range(1, monitor.cfg.workers+1))
         for philosopher in monitor.managed_actors.values():
@@ -211,8 +216,7 @@ action to the monitor.'''
         params.update({'name': name,
                        'number': number,
                        'forks': []})
-        return params
-    
+
 
 if __name__ == '__main__':
-    DiningPhilosophers().start()
\ No newline at end of file
+    DiningPhilosophers().start()
