@@ -4,7 +4,7 @@ framework is built on top of pulsar asynchronous engine and allows to
 implement servers with very little effort. The main classes here are:
 :class:`Application` and :class:`MultiApp` which, has the name suggests, is
 a factory of several :class:`Application` running on a single server.
-The :class:`Configurator` is a mixin used as base class for both 
+The :class:`Configurator` is a mixin used as base class for both
 :class:`Application` and :class:`MultiApp`.
 
 .. note::
@@ -15,50 +15,34 @@ The :class:`Configurator` is a mixin used as base class for both
 
 Configurator
 ===============================
-   
+
 .. autoclass:: Configurator
    :members:
    :member-order: bysource
-   
-   
+
+
 Application
 ===============================
-   
+
 .. autoclass:: Application
    :members:
    :member-order: bysource
-   
+
 
 Multi App
 ===============================
-      
+
 .. autoclass:: MultiApp
    :members:
    :member-order: bysource
-   
-   
+
+
 Get application
 =========================
 
 .. autofunction:: get_application
 
 
-Application Worker
-===============================
-   
-.. autoclass:: Worker
-   :members:
-   :member-order: bysource
-
-
-Application Monitor
-===============================
-   
-.. autoclass:: ApplicationMonitor
-   :members:
-   :member-order: bysource
-   
-
 Backend
 ===================
 
@@ -72,24 +56,23 @@ from hashlib import sha1
 from inspect import getfile
 
 import pulsar
-from pulsar import Actor, Monitor, get_actor, EventHandler, async
+from pulsar import get_actor, EventHandler
 from pulsar.utils.structures import OrderedDict
 from pulsar.utils.pep import pickle
-from pulsar.utils.internet import parse_connection_string, get_connection_string
-from pulsar.utils.log import LocalMixin
+from pulsar.utils.internet import (parse_connection_string,
+                                   get_connection_string)
+from pulsar.utils.log import LocalMixin, local_property
 from pulsar.utils.importer import import_module
 
 __all__ = ['Application',
            'MultiApp',
            'Backend',
-           'Worker',
-           'ApplicationMonitor',
            'get_application']
-    
-    
+
+
 def get_application(name):
     '''Fetch the :class:`Application` associated with ``name`` if available.
-    
+
 This function may return an :ref:`asynchronous component <coroutine>`.
 The application name is set during initialisation. Check the
 :attr:`Configurator.name` attribute for more information.
@@ -100,145 +83,133 @@ The application name is set during initialisation. Check the
             return _get_app(actor, name)
         else:
             return actor.send('arbiter', 'run', _get_app, name)
-        
+
+
 def _get_app(arbiter, name):
     monitor = arbiter.get_actor(name)
     if monitor:
         return monitor.params.app
 
-@async()
+
 def monitor_start(self):
+    app = self.params.app
+    self.app = app
+    self.bind_event('on_params', monitor_params)
+    self.bind_event('on_info', monitor_info)
+    self.bind_event('stopping', monitor_stopping)
+    self.bind_event('stop', monitor_stop)
+    self.monitor_task = lambda: app.monitor_task(self)
     yield self.app.monitor_start(self)
     if not self.cfg.workers:
         yield self.app.worker_start(self)
     self.app.fire_event('start')
-        
+    yield self  # yield self as last. Part of the start event chain
+
+
+def monitor_stopping(self):
+    if not self.cfg.workers:
+        yield self.app.worker_stopping(self)
+    yield self.app.monitor_stopping(self)
+    yield self
+
+
 def monitor_stop(self):
     if not self.cfg.workers:
-        self.app.worker_stop(self)
-    self.app.monitor_stop(self)
+        yield self.app.worker_stop(self)
+    yield self.app.monitor_stop(self)
+    yield self.app.fire_event('stop')
+    yield self
+
+
+def monitor_info(self, info=None):
+    if not self.cfg.workers:
+        self.app.worker_info(self, info)
+    else:
+        self.app.monitor_info(self, info)
+
+
+def monitor_params(self, params=None):
+    app = self.app
+    if self.cfg.concurrency == 'thread':
+        app = pickle.loads(pickle.dumps(app))
+    params.update({'app': app,
+                   'name': '{0}-worker'.format(app.name),
+                   'start': worker_start})
+    app.actorparams(self, params)
+
+
+def worker_start(self):
+    app = self.params.app
+    self.app = app
+    self.bind_event('on_info', app.worker_info)
+    self.bind_event('stopping', app.worker_stopping)
+    self.bind_event('stop', app.worker_stop)
+    return app.worker_start(self)
+
 
 def arbiter_config(cfg):
     cfg = cfg.copy()
     for setting in list(cfg.settings.values()):
-        if setting.app: # Don't include application specific settings
+        if setting.app:  # Don't include application specific settings
             cfg.settings.pop(setting.name)
         elif not setting.is_global:
             if not getattr(setting, 'inherit', False):
                 setting.set(setting.default)
-    return cfg 
+    return cfg
 
 
-class Worker(Actor):
-    '''An :class:`pulsar.Actor` for serving a pulsar :class:`Application`.'''
-    def __init__(self, *args, **kwargs):
-        super(Worker, self).__init__(*args, **kwargs)
-        self.bind_event('start', self.app.worker_start)
-        self.bind_event('stopping', self.app.worker_stopping)
-        self.bind_event('stop', self.app.worker_stop)
-        
-    @property
-    def app(self):
-        '''The :class:`Application` served by this :class:`Worker`.'''
-        return self.params.app
-    
-    def info(self):
-        data = super(Worker, self).info()
-        return self.app.worker_info(self, data)
-    
-
-class ApplicationMonitor(Monitor):
-    '''A :class:`pulsar.Monitor` for managing a pulsar :class:`Application`.'''
-    actor_class = Worker
-    
-    def __init__(self, *args, **kwargs):
-        super(ApplicationMonitor, self).__init__(*args, **kwargs)
-        self.bind_event('start', monitor_start)
-        self.bind_event('stop', monitor_stop)
-        
-    @property
-    def app(self):
-        '''The :class:`Application` served by this
-:class:`ApplicationMonitor`.'''
-        return self.params.app
-        
-    ############################################################################
-    # Delegates Callbacks to the application
-    def monitor_task(self):
-        self.app.monitor_task(self)
-        
-    def actorparams(self):
-        p = Monitor.actorparams(self)
-        app = self.app
-        if self.cfg.concurrency == 'thread':
-            app = pickle.loads(pickle.dumps(app))
-        p.update({'app': app,
-                  'name': '{0}-worker'.format(app.name)})
-        return self.app.actorparams(self, p)
-    
-    def info(self):
-        data = super(ApplicationMonitor, self).info()
-        if not self.cfg.workers:
-            return self.app.worker_info(self, data)
-        else:
-            return self.app.monitor_info(self, data)
-        
-
-
-class AppEvents(EventHandler):
-    ONE_TIME_EVENTS = ('ready', 'start', 'stop')
-    
-
 class Configurator(object):
-    '''A mixin for configuring and loading the various necessities for any
-given server running on :mod:`pulsar` concurrent framework.
+    '''A mixin for configuring and loading a pulsar server.
 
-:parameter name: to override the class :attr:`name` attribute.
-:parameter description: to override the class :attr:`cfg.description` attribute.
-:parameter epilog: to override the class :attr:`cfg.epilog` attribute.
-:parameter version: Optional version of this application, it overrides the
-    class :attr:`cfg.version` attribute.
-:parameter argv: Optional list of command line parameters to parse, if
-    not supplied the :attr:`sys.argv` list will be used. The parameter is
-    only relevant if **parse_console** is ``True``.
-:parameter parse_console: ``True`` (default) if the console parameters needs
-    parsing.
-:parameter script: Optional string which set the :attr:`script` attribute.
-:parameter params: a dictionary of configuration parameters which overrides
-    the defaults and the :attr:`cfg` class attribute. They will be overritten
-    by a :ref:`config file <setting-config>` or command line
-    arguments.   
+    :parameter name: to override the class :attr:`name` attribute.
+    :parameter description: to override the class :attr:`cfg.description`
+        attribute.
+    :parameter epilog: to override the class :attr:`cfg.epilog` attribute.
+    :parameter version: Optional version of this application, it overrides
+        the class :attr:`cfg.version` attribute.
+    :parameter argv: Optional list of command line parameters to parse, if
+        not supplied the :attr:`sys.argv` list will be used. The parameter
+        is only relevant if **parse_console** is ``True``.
+    :parameter parse_console: ``True`` (default) if the console parameters
+        needs parsing.
+    :parameter script: Optional string which set the :attr:`script`
+        attribute.
+    :parameter params: a dictionary of configuration parameters which
+        overrides the defaults and the :attr:`cfg` class attribute.
+        They will be overritten by a :ref:`config file <setting-config>`
+        or command line arguments.
 
-.. attribute:: name
-    
-    The name is unique if this is an :class:`Application`. In this
-    case it defines the application monitor name as well and can be access in
-    the arbiter domain via the :func:`get_application` function.
-    
-.. attribute:: argv
+    .. attribute:: name
 
-    Optional list of command line parameters. If not available the
-    :attr:`sys.argv` list will be used when parsing the console.
-    
-.. attribute:: cfg
+        The name is unique if this is an :class:`Application`. In this
+        case it defines the application monitor name as well and can be
+        access in the arbiter domain via the :func:`get_application`
+        function.
 
-    The :class:`pulsar.utils.config.Config` for this :class:`Configurator`.
-    If set as class attribute it will be replaced during initialisation.
+    .. attribute:: argv
 
-    Default: ``None``.
+        Optional list of command line parameters. If not available the
+        :attr:`sys.argv` list will be used when parsing the console.
 
-.. attribute:: parsed_console
+    .. attribute:: cfg
 
-    ``True`` if this application parsed the console before starting.
-    
-.. attribute:: script
+        The :class:`pulsar.utils.config.Config` for this :class:`Configurator`.
+        If set as class attribute it will be replaced during initialisation.
 
-    Full path of the script which starts the application or ``None``.
-    Evaluated during initialization via the :meth:`python_path` method.
-'''
+        Default: ``None``.
+
+    .. attribute:: parsed_console
+
+        ``True`` if this application parsed the console before starting.
+
+    .. attribute:: script
+
+        Full path of the script which starts the application or ``None``.
+        Evaluated during initialization via the :meth:`python_path` method.
+    '''
     name = None
     cfg = None
-    
+
     def __init__(self,
                  name=None,
                  description=None,
@@ -260,28 +231,31 @@ given server running on :mod:`pulsar` concurrent framework.
         self.cfg.description = description or self.cfg.description
         self.cfg.epilog = epilog or self.cfg.epilog
         self.cfg.version = version or self.cfg.version
+        self.cfg.name = self.name
         self.argv = argv
         self.parsed_console = parse_console
         self.script = self.python_path(script)
-    
+
     @property
     def version(self):
         '''Version of this :class:`Application`'''
         return self.cfg.version
-    
+
     @property
     def root_dir(self):
-        '''Root directory of this :class:`Configurator`. Evaluated from the
-:attr:`script` attribute.'''
+        '''Root directory of this :class:`Configurator`.
+
+        Evaluated from the :attr:`script` attribute.
+        '''
         if self.script:
             return os.path.dirname(self.script)
-    
+
     def __repr__(self):
         return self.name
 
     def __str__(self):
         return self.__repr__()
-    
+
     def python_path(self, script):
         '''Called during initialization to obtain the ``script`` name and
 to add the :attr:`script` directory to the python path if not in the
@@ -300,13 +274,17 @@ script which runs the application.'''
         if path not in sys.path:
             sys.path.insert(0, path)
         return script
-    
-    def on_config(self):
-        '''Callback when configuration is loaded. This is a chance to do
- an application specific check before the concurrent machinery is put into
- place. If it returns ``False`` the application will abort.'''
+
+    def on_config(self, arbiter):
+        '''Callback when configuration is loaded.
+
+        This is a chance to do applications specific checks before the
+        concurrent machinery is put into place.
+
+        If it returns ``False`` the application will abort.
+        '''
         pass
-    
+
     def load_config(self):
         '''Load the application configuration from a file and/or
 from the command line. Called during application initialization.
@@ -330,7 +308,9 @@ The parameters overriding order is the following:
                     self.cfg.set(setting.name, setting.get())
         for name in list(self.cfg.params):
             if name in self.cfg.settings:
-                self.cfg.params.pop(name)
+                value = self.cfg.params.pop(name)
+                if value is not None:
+                    self.cfg.set(name, value)
         # parse console args
         if self.parsed_console:
             parser = self.cfg.parser()
@@ -351,11 +331,12 @@ The parameters overriding order is the following:
                 if v is None:
                     continue
                 self.cfg.set(k.lower(), v)
-    
+
     @classmethod
     def create_config(cls, params, prefix=None, name=None):
-        '''Create a new :class:`pulsar.utils.config.Config` container by
-overriding default values with *params*.'''
+        '''Create a new :class:`pulsar.utils.config.Config` container.
+
+        Overrides defaults with ``params``.'''
         if cls.cfg:
             cfg = cls.cfg.copy(name=name, prefix=prefix)
             # update with latest settings
@@ -364,58 +345,47 @@ overriding default values with *params*.'''
         else:
             cfg = pulsar.Config(name=name, prefix=prefix, **params)
         return cfg
-    
-    
+
+
 class Application(Configurator, pulsar.Pulsar):
-    """An application interface for configuring and loading
-the various necessities for any given server or distributed application running
-on :mod:`pulsar` concurrent framework.
-Applications can be of any sorts or forms and the library is shipped with
-several battery included examples in the :mod:`pulsar.apps` framework module.
+    """An application interface.
 
-These are the most important facts about a pulsar :class:`Application`:
+    Applications can be of any sorts or forms and the library is shipped with
+    several battery included examples in the :mod:`pulsar.apps` framework
+    module.
 
-* It derives from :class:`Configurator` so that it has all the functionalities
-  to parse command line arguments and setup the :attr:`Configurator.cfg`.
-* Instances must be picklable. If non-picklable data needs to be add on an
-  :class:`Application` instance, it must be stored on the
-  :attr:`Application.local` dictionary.
-* Instances of an :class:`Application` are callable objects.
-* When an :class:`Application` is called for the first time,
-  a new :class:`ApplicationMonitor` instance is added to the
-  :class:`pulsar.Arbiter`, ready to perform its duties.
+    These are the most important facts about a pulsar :class:`Application`:
 
-:parameter callable: Initialise the :attr:`Application.callable` attribute.
-:parameter load_config: If ``False`` the :meth:`Configurator.load_config`
-    is not invoked. Default ``True``.
-:parameter params: Passed to the :class:`Configurator` initialiser.
+    * It derives from :class:`Configurator` so that it has all the
+    functionalities to parse command line arguments and setup the
+    :attr:`Configurator.cfg`.
+    * Instances must be picklable. If non-picklable data needs to be add on an
+      :class:`Application` instance, it must be stored on the
+      :attr:`Application.local` dictionary.
+    * Instances of an :class:`Application` are callable objects.
+    * When an :class:`Application` is called for the first time,
+      a new :class:`pulsar.Monitor` instance is added to the
+      :class:`pulsar.Arbiter`, ready to perform its duties.
 
-.. attribute:: callable
+    :parameter callable: Initialise the :attr:`Application.callable` attribute.
+    :parameter load_config: If ``False`` the :meth:`Configurator.load_config`
+        is not invoked. Default ``True``.
+    :parameter params: Passed to the :class:`Configurator` initialiser.
 
-    Optional callable serving or configuring your application.
-    If provided, the callable must be picklable, therefore it is either
-    a function or a picklable object.
+    .. attribute:: callable
 
-    Default ``None``
-"""
+        Optional callable serving or configuring your application.
+        If provided, the callable must be picklable, therefore it is either
+        a function or a picklable object.
+
+        Default ``None``
+    """
     def __init__(self, callable=None, load_config=True, **params):
-        '''Initialize a new :class:`Application` and add its
-:class:`ApplicationMonitor` to the class:`pulsar.Arbiter`.
-
-:parameter version: Optional version number of the application.
-
-    Default: ``pulsar.__version__``
-
-:parameter parse_console: flag for parsing console inputs. By default it parse
-    only if the arbiter has not yet started.
-'''
         super(Application, self).__init__(load_config=load_config, **params)
-        self.local.events = AppEvents()
         self.callable = callable
         if load_config:
             self.load_config()
-        self()
-        
+
     def __call__(self, actor=None):
         if actor is None:
             actor = get_actor()
@@ -427,92 +397,105 @@ These are the most important facts about a pulsar :class:`Application`:
             self.configure_logging()
             self.fire_event('ready')
             arbiter = pulsar.arbiter(cfg=arbiter_config(self.cfg))
-            if self.on_config() is not False:
-                monitor = arbiter.add_monitor(ApplicationMonitor,
-                                              self.name,
-                                              app=self,
-                                              cfg=self.cfg)
-                self.cfg = monitor.cfg
+            if self.on_config(arbiter) is not False:
+                if arbiter.started():
+                    self._add_to_arbiter(arbiter)
+                else:   # the arbiter has not yet started.
+                    arbiter.bind_event('start', self._add_to_arbiter)
+            else:
+                return
         return self.event('start')
-        
-    @property
-    def app(self):
-        '''Returns ``self``. Implemented so that the :class:`ApplicationMonitor`
-and the :class:`Application` have the same interface.'''
-        return self
+
+    @local_property
+    def events(self):
+        '''Events for the application: ``ready```, ``start``, ``stop``.'''
+        return EventHandler(one_time_events=('ready', 'start', 'stop'))
 
     @property
-    def monitor(self):
-        actor = get_actor()
-        if actor:
-            return actor.registered.get(self.name)
+    def stream(self):
+        '''Actor stream handler.
+        '''
+        return get_actor().stream
+
+    def fire_event(self, name, **kw):
+        '''Fire event ``name``.'''
+        return self.events.fire_event(name, self, **kw)
 
-    def __setstate__(self, state):
-        super(Application, self).__setstate__(state)
-        self.local.events = AppEvents()
-        
-    def fire_event(self, name):
-        return self.local.events.fire_event(name, self)
-        
     def bind_event(self, name, callback):
-        return self.local.events.bind_event(name, callback)
-        
+        '''Bind ``callback`` to event ``name``.'''
+        return self.events.bind_event(name, callback)
+
     def event(self, name):
-        return self.local.events.event(name)
+        '''Return the event ``name``.'''
+        return self.events.event(name)
 
-    def add_timeout(self, deadline, callback):
-        self.arbiter.event_loop.add_timeout(deadline, callback)
-    
     # WORKERS CALLBACKS
     def worker_start(self, worker):
         '''Added to the ``start`` :ref:`worker hook <actor-hooks>`.'''
         pass
 
-    def worker_info(self, worker, info):
-        '''Hook to add additional entries to the worker ``info`` dictionary.'''
-        return info
-    
+    def worker_info(self, worker, info=None):
+        '''Hook to add additional entries to the worker ``info`` dictionary.
+        '''
+        pass
+
     def worker_stopping(self, worker):
         '''Added to the ``stopping`` :ref:`worker hook <actor-hooks>`.'''
         pass
-    
+
     def worker_stop(self, worker):
         '''Added to the ``stop`` :ref:`worker hook <actor-hooks>`.'''
         pass
 
     # MONITOR CALLBACKS
-    def actorparams(self, monitor, params):
-        '''A chance to override the dictionary of parameters *params*
-before a new :class:`Worker` is spawned. This method is invoked by
-the :class:`ApplicationMonitor`. By default it does nothing.'''
-        return params
+    def actorparams(self, monitor, params=None):
+        '''Hook to add additional entries when the monitor spawn new actors.
+        '''
+        pass
 
     def monitor_start(self, monitor):
-        '''Callback by :class:`ApplicationMonitor` when starting.
-The application is now in the arbiter but has not yet started.'''
+        '''Callback by the monitor when starting.
+        '''
+        pass
+
+    def monitor_info(self, monitor, info=None):
+        '''Hook to add additional entries to the monitor ``info`` dictionary.
+        '''
+        pass
+
+    def monitor_stopping(self, monitor):
+        '''Callback by the monitor before stopping.
+        '''
         pass
 
-    def monitor_info(self, monitor, data):
-        '''Hook to add additional entries to the monitor ``info`` dictionary.'''
-        return data
-    
     def monitor_stop(self, monitor):
-        '''Callback by :class:`ApplicationMonitor` when stopping'''
+        '''Callback by the monitor on stop.
+        '''
         pass
 
     def monitor_task(self, monitor):
-        '''Callback by :class:`ApplicationMonitor` at each event loop'''
+        '''Callback by the monitor at each event loop.'''
         pass
-    
+
     def start(self):
         '''Start the :class:`pulsar.Arbiter` if it wasn't already started.
-Calling this method when the :class:`pulsar.Arbiter` is already running has
-no effect.'''
+
+        Calling this method when the :class:`pulsar.Arbiter` is already
+        running has no effect.
+        '''
+        on_start = self()
         arbiter = pulsar.arbiter()
-        if arbiter and self.name in arbiter.registered:
+        if arbiter and on_start:
             arbiter.start()
         return self
 
+    #   INTERNALS
+    def _add_to_arbiter(self, arbiter):
+        monitor = arbiter.add_monitor(
+            self.name, app=self, cfg=self.cfg, start=monitor_start)
+        self.cfg = monitor.cfg
+        return arbiter
+
 
 class MultiApp(Configurator):
     '''A :class:`MultiApp` is a tool for creating several :class:`Application`
@@ -527,7 +510,7 @@ supports all its configuration utilities.
 A minimal example usage::
 
     import pulsar
-    
+
     class Server(pulsar.MultiApp):
         def build(self):
             yield self.new_app(TaskQueue)
@@ -535,21 +518,22 @@ A minimal example usage::
             yield self.new_app(WSGIserver, prefix="web", callable=..., ...)
 '''
     _apps = None
-    
+
     def build(self):
         '''Virtual method, must be implemented by subclasses and return an
 iterable over results obtained from calls to the :meth:`new_app` method.'''
         raise NotImplementedError
-    
+
     def apps(self):
         '''List of :class:`Application` for this :class:`MultiApp`.
 The list is lazily loaded from the :meth:`build` method.'''
         if self._apps is None:
             # Add non-default settings values to the list of cfg params
-            self.cfg.params.update(((s.name, s.value) for s in\
-                       self.cfg.settings.values() if s.value != s.default))
+            self.cfg.params.update(((s.name, s.value) for s in
+                                    self.cfg.settings.values() if
+                                    s.value != s.default))
             self.cfg.settings = {}
-            self._apps =  []
+            self._apps = []
             apps = OrderedDict(self.build())
             if not apps:
                 return self._apps
@@ -566,9 +550,11 @@ The list is lazily loaded from the :meth:`build` method.'''
                     new_settings[setting.name] = setting
                 cfg.settings = new_settings
                 kwargs.update({'name': name, 'cfg': cfg, 'callable': callable})
-                self._apps.append(App(**kwargs))
+                app = App(**kwargs)
+                app()
+                self._apps.append(app)
         return self._apps
-    
+
     def new_app(self, App, prefix=None, callable=None, **params):
         '''Invoke this method in the :meth:`build` method as many times
 as the number of :class:`Application` required by this :class:`MultiApp`.
@@ -597,26 +583,27 @@ as the number of :class:`Application` required by this :class:`MultiApp`.
             if k not in self.cfg.settings:
                 self.cfg.settings[k] = cfg.settings[k]
         return prefix, (App, name, callable, cfg)
-            
+
     def __call__(self, actor=None):
         return pulsar.multi_async((app(actor) for app in self.apps()))
-        
+
     def start(self):
         '''Use this method to start all applications at once.'''
         self.apps()
         arbiter = pulsar.arbiter()
         if arbiter:
             arbiter.start()
-    
+
     ##    INTERNALS
     def _iter_app(self, app_name_callables):
         main = app_name_callables.pop('', None)
         if not main:
-            raise pulsar.ImproperlyConfigured('No main application in MultiApp')
+            raise pulsar.ImproperlyConfigured(
+                'No main application in MultiApp')
         yield main
         for app in app_name_callables.values():
             yield app
-    
+
     def _get_app_params(self):
         params = self.cfg.params.copy()
         for key, value in self.__dict__.items():
@@ -627,75 +614,80 @@ as the number of :class:`Application` required by this :class:`MultiApp`.
             params[key] = value
         params['load_config'] = False
         return params
-    
-    
+
+
 class Backend(LocalMixin):
-    '''Base class for backends. It is the base class for
-:ref:`publish/subscribe backend <apps-pubsub>` and for the
-:ref:`taskqueue backend <apps-taskqueue>`.
-A :class:`Backend` is never initialised directly, the
-:meth:`Backend.make` classmethod is used instead.
+    '''Base class for backends.
 
-.. attribute:: scheme
+    It is the base class for :ref:`publish/subscribe backend <apps-pubsub>`
+    and for the :ref:`taskqueue backend <apps-taskqueue>`.
 
-    The scheme for this backend (``local``, ``redis``, ``http``, ...).
-    
-.. attribute:: name
+    A :class:`Backend` is never initialised directly, the
+    :meth:`Backend.make` classmethod is used instead.
 
-    Optional name of the :class:`Application` which created this
-    :class:`Backend`. If not available the ``arbiter`` is used as owner
-    of this :class:`Backend`.
-    
-.. attribute:: params
+    .. attribute:: scheme
 
-    Dictionary of additional parameters passed during initialisation.
-    
-.. attribute:: connection_string
+        The scheme for this backend (``local``, ``redis``, ``http``, ...).
 
-    The connection string fro this backend. It is always in the form::
-    
-        scheme:://address?param1=..&params2=... &...
-        
-    where ``address`` is usually a ``host:port`` string.
-    
-    A special connection string is::
-    
-        local://&param1=...&...
-        
-    which represents a backend implemented using pulsar itself. A local backend
-    is installed in the monitor managing the :class:`Application` which
-    createded it.
-    
-.. attribute:: default_path
+    .. attribute:: name
 
-    A class attribute which represents the path from where to load backend
-    implementations.
-'''
+        Optional name of the :class:`Application` which created this
+        :class:`Backend`. If not available the ``arbiter`` is used as owner
+        of this :class:`Backend`.
+
+    .. attribute:: params
+
+        Dictionary of additional parameters passed during initialisation.
+        These parameters are first pre-processed by the :meth:`setup`
+        method.
+
+    .. attribute:: connection_string
+
+        The connection string fro this backend. It is always in the form::
+
+            scheme:://address?param1=..&params2=... &...
+
+        where ``address`` is usually a ``host:port`` string.
+
+        A special connection string is::
+
+            local://&param1=...&...
+
+        which represents a backend implemented using pulsar itself.
+        A local backend is installed in the monitor registered with
+        :attr:`name`.
+
+    .. attribute:: default_path
+
+        A class attribute which represents the path from where to load backend
+        implementations.
+    '''
     def __init__(self, scheme, connection_string, name=None, **params):
         self.scheme = scheme
         self.name = name or 'arbiter'
         self.connection_string = connection_string
         self.params = dict(self.setup(**params) or {})
         self._id = sha1(str(self).encode('utf-8')).hexdigest()
-        
+
     def __repr__(self):
         return '%s. %s' % (self.__class__.__name__, self.connection_string)
     __str__ = __repr__
-    
+
     def setup(self, **params):
         return params
-    
+
     @property
     def id(self):
-        '''Identy for this backend, calculated from the class name and the
-:attr:`connection_string`. Therefore if two backend instances from
-the same class have the same connection string, than the :attr:`id`
-is the same.
+        '''Identy for this backend.
 
-The :attr:`id`` is important when creating a new backend via the
-:meth:`make` method.'''
+        It is calculated from the class name and the
+        :attr:`connection_string`.
+
+        Therefore, if two backend instances from the same class have the
+        same connection string, than the :attr:`id` is the same.
+        '''
         return self._id
-    
+
     @classmethod
     def make(cls, backend=None, name=None, **kwargs):
         '''Create a new :class:`Backend` from a *backend* connection string
@@ -706,11 +698,11 @@ which is of the form::
 For example, a parameter-less local backend is::
 
     local://
-    
+
 A redis backend could be::
 
     redis://127.0.0.1:6379?db=1&password=bla
-    
+
 :param backend: the connection string, if not supplied ``local://`` is used.
 :param kwargs: additional key-valued parameters used by the :class:`Backend`
     during initialisation.
@@ -732,7 +724,7 @@ A redis backend could be::
         if 'timeout' in params:
             params['timeout'] = int(params['timeout'])
         return bcls(scheme, con_str, **params)
-    
+
     @classmethod
     def get_connection_string(cls, scheme, address, params, name):
         '''Create the connection string used during initialisation
@@ -740,9 +732,9 @@ A redis backend could be::
         if name:
             params['name'] = name
         return get_connection_string(scheme, address, params)
-    
+
     @classmethod
     def path_from_scheme(cls, scheme):
         '''A class method which returns the import dotted path for a given
 ``scheme``. Must be implemented by subclasses.'''
-        raise NotImplementedError
\ No newline at end of file
+        raise NotImplementedError
