@@ -6,10 +6,11 @@ a django web site with pulsar. Add it to the list of your ``INSTALLED_APPS``::
         'pulsar.apps.pulse',
         ...
     )
-    
+
 and run the site via the ``pulse`` command::
 
     python manage.py pulse
 
-
-'''
\ No newline at end of file
+Check the :ref:`django chat example <tutorials-django>` for a django chat
+application served by a multiprocessing pulsar server.
+'''
