@@ -6,9 +6,8 @@ STARTED = "STARTED"
 RETRY = "RETRY"
 QUEUED = "QUEUED"
 PENDING = "PENDING"
-#: Lower index means higher precedence.
-PRECEDENCE = (
-              (SUCCESS, 1),
+# Lower index means higher precedence.
+PRECEDENCE = ((SUCCESS, 1),
               (FAILURE, 2),
               (UNKNOWN, 3),
               (REVOKED, 4),
@@ -28,4 +27,4 @@ EXCEPTION_STATES = frozenset([RETRY, FAILURE, REVOKED])
 PROPAGATE_STATES = frozenset([FAILURE, REVOKED])
 ALL_STATES = frozenset([QUEUED, PENDING, STARTED, SUCCESS, FAILURE,
                         RETRY, REVOKED])
-status_code = lambda code: PRECEDENCE_MAPPING.get(code)
\ No newline at end of file
+status_code = lambda code: PRECEDENCE_MAPPING.get(code)
