@@ -34,13 +34,21 @@ called ``tests`` in the ``examples`` module.
 To run the test suite::
 
     python runtests.py
-    
+
 Type::
 
     python runtests.py --help
-    
+
 For a list different options/parameters which can be used when running tests.
 
+.. note::
+
+    Pulsar test suite help you speed up your tests!
+    Use ``setUpClass`` rather than ``setUp``, use asynchronous tests and if
+    not possible add fire power with more test workers.
+
+    Try with the ``-w 8`` command line input for a laugh.
+
 The next step is to actually write the tests.
 
 Writing a Test Case
@@ -61,18 +69,18 @@ An example test case::
     # Otherwise it is the same as
     #     import unittest
     from pulsar.apps.test import unittest
-    
+
     class MyTest(unittest.TestCase):
-        
+
         def test_async_test(self):
             result = yield maybe_async_function()
             self.assertEqual(result, ...)
-            
+
         def test_simple_test(self):
             self.assertEqual(1, 1)
 
 .. note::
-    
+
     Test functions are asynchronous, when they return a generator or a
     :class:`pulsar.Deferred`, synchronous, when they return anything else.
 
@@ -89,7 +97,7 @@ initialising the :class:`TestSuite`::
     if __name__ == '__main__':
         TestSuite(modules=('tests',
                           ('examples','tests'))).start()
-                           
+
 The :class:`TestSuite` loads tests via the :class:`loader.TestLoader` class.
 
 In the context of explaining the rules for loading tests, we refer to
@@ -97,7 +105,7 @@ an ``object`` as
 
 * a ``module`` (including a directory module)
 * a python ``class``.
-    
+
 with this in mind:
 
 * Directories that aren't packages are not inspected. This means that if a
@@ -108,31 +116,31 @@ with this in mind:
 * If an ``object`` defines a ``__test__`` attribute that does not evaluate to
   ``True``, that object will not be collected, nor will any ``objects``
   it contains.
-  
+
 The ``modules`` parameter is a tuple or list of entries where each single
 ``entry`` follows the rules:
 
-* If the ``entry`` is a string, it indicates the **dotted path** relative to the
-  **root** directory (the directory of the script running the tests). For
-  example::
-  
+* If the ``entry`` is a string, it indicates the **dotted path** relative
+  to the **root** directory (the directory of the script running the tests).
+  For example::
+
       modules = ['tests', 'moretests.here']
-  
+
 * If an entry is two elements tuple, than the first element represents
   a **dotted path** relative to the **root** directory and the
   second element a **pattern** which modules (files or directories) must match
   in order to be included in the search. For example::
-  
+
       modules = [...,
                  ('examples', 'test*')
                  ]
-  
+
   load modules, from inside the ``examples`` module, starting with ``test``.
-  
+
 * If an entry is a three elements tuple, it is the same as the *two elements
   tuple* rule with the third element which specifies the top level **tag**
   for all tests in this entry. For example::
-  
+
       modules = [...,
                   ('bla', '*', 'foo')
                 ]
@@ -142,11 +150,12 @@ For example, the following::
     modules = ['test', ('bla', '*', 'foo'), ('examples','test*')]
 
 loads
-    
+
 * all tests from modules in the ``test`` directory,
 * all tests from the ``bla`` directory with top level tag ``foo``,
-* all tests from modules which starts with *test* from the ``examples`` directory.
-     
+* all tests from modules which starts with *test* from the ``examples``
+  directory.
+
 All top level modules will be added to the python ``path``.
 
 
@@ -171,24 +180,24 @@ the :class:`TestSuite`
 forces tests to be run in a sequential model, one after the other::
 
     python runtests.py --sequential
-    
-Alternatively, if you need to specify a Testcase which always runs its test functions
-in a sequential way, you can use the :func:`sequential` decorator::
+
+Alternatively, if you need to specify a Testcase which always runs its test
+functions in a sequential way, you can use the :func:`sequential` decorator::
 
     from pulsar.apps.test import unittest, sequential
-    
+
     @sequential
     class MyTestCase(unittest.TestCase):
         ...
-        
-        
+
+
 list labels
 ~~~~~~~~~~~~~~~~~~~
-By passing the ``-l`` or :ref:`--list-labels <setting-list_labels>` flag to the command line, the
-full list of test labels available is displayed::
+By passing the ``-l`` or :ref:`--list-labels <setting-list_labels>` flag
+to the command line, the full list of test labels available is displayed::
 
     python runtests.py -l
-    
+
 
 test timeout
 ~~~~~~~~~~~~~~~~~~~
@@ -197,7 +206,7 @@ long a test function can wait for results. This is what the
 :ref:`--test-timeout <setting-test_timeout>` command line flag does::
 
     python runtests.py --test-timeout 10
-    
+
 Set the test timeout to 10 seconds.
 
 
@@ -266,7 +275,7 @@ Test Plugin
 .. autoclass:: TestPlugin
    :members:
    :member-order: bysource
-   
+
 .. _unittest2: http://pypi.python.org/pypi/unittest2
 .. _mock: http://pypi.python.org/pypi/mock
 
@@ -279,8 +288,8 @@ Utilities
 import sys
 
 import pulsar
+from pulsar import EventHandler, maybe_failure
 from pulsar.apps import tasks
-from pulsar.utils import events
 from pulsar.utils.log import local_property
 from pulsar.utils.config import section_docs
 from pulsar.utils.pep import default_timer
@@ -296,18 +305,26 @@ section_docs['Test'] = '''
 This section covers configuration parameters used by the
 :ref:`Asynchronous/Parallel test suite <apps-test>`.'''
 
+
 def dont_run_with_thread(obj):
-    '''Decorator for disabling test cases when the test suite runs in
-threading, rather than processing, mode.'''
+    '''Decorator for disabling process baaed test cases when the test suite
+    runs in threading, rather than processing, mode.
+    '''
     actor = pulsar.get_actor()
     if actor:
-        d = unittest.skipUnless(actor.cfg.concurrency=='process',
+        d = unittest.skipUnless(actor.cfg.concurrency == 'process',
                                 'Run only when concurrency is process')
         return d(obj)
     else:
         return obj
 
 
+def mute_failure(test, failure):
+    #TODO: add test flag to control muting
+    if not test.cfg.log_failures:
+        maybe_failure(failure).mute()
+
+
 class ExitTest(Exception):
     pass
 
@@ -318,8 +335,8 @@ class TestVerbosity(TestOption):
     type = int
     default = 1
     desc = """Test verbosity, 0, 1, 2, 3"""
-    
-    
+
+
 class TestTimeout(TestOption):
     name = 'test_timeout'
     flags = ['--test-timeout']
@@ -335,10 +352,11 @@ class TestLabels(TestOption):
     name = "labels"
     nargs = '*'
     validator = pulsar.validate_list
-    desc = """Optional test labels to run. If not provided\
- all tests are run.
+    desc = """Optional test labels to run.
 
-To see available labels use the -l option."""
+    If not provided all tests are run.
+    To see available labels use the -l option.
+    """
 
 
 class TestExcludeLabels(TestOption):
@@ -359,12 +377,12 @@ class TestSize(TestOption):
 
 class TestList(TestOption):
     name = "list_labels"
-    flags = ['-l','--list-labels']
+    flags = ['-l', '--list-labels']
     action = 'store_true'
     default = False
     validator = pulsar.validate_bool
     desc = """List all test labels without performing tests."""
-    
+
 
 class TestSequential(TestOption):
     name = "sequential"
@@ -372,68 +390,98 @@ class TestSequential(TestOption):
     action = 'store_true'
     default = False
     validator = pulsar.validate_bool
-    desc = """Run test functions sequentially. Don't run them asynchronously."""
-    
-    
+    desc = """Run test functions sequentially.
+
+    Don't run them asynchronously.
+    """
+
+
 class TestShowLeaks(TestOption):
     name = "show_leaks"
     flags = ['--show-leaks']
+    nargs = '?'
+    choices = (0, 1, 2)
+    const = 1
+    type = int
+    default = 0
+    desc = """Shows memory leaks.
+
+    Run the garbadge collector before a process-based actor dies and shows
+    the memory leak report."""
+
+
+class TestLogFailures(TestOption):
+    name = "log_failures"
+    flags = ['--log-failures']
     action = 'store_true'
     default = False
     validator = pulsar.validate_bool
-    desc = """Shows memory leaks.
-    
-    Run the garbadge collector before a process-based actor dies and shows
-    the memory leak report."""
-    
+    desc = """Don't mute exceptions.
+
+    Tested exception are usually muted via mute_failure function. This
+    flag disable it.
+
+    To see the exception the log level must be at least error."""
+
+
+class TestCoveralls(TestOption):
+    name = 'coveralls'
+    flags = ['--coveralls']
+    action = 'store_true'
+    default = False
+    validator = pulsar.validate_bool
+    desc = """Send coverage report to coveralls.io."""
+
 
 pyver = '%s.%s' % (sys.version_info[:2])
 
+
 class TestSuite(tasks.TaskQueue):
-    '''An asynchronous test suite which works like a task queue where each task
-is a group of tests specified in a test class.
+    '''An asynchronous test suite which works like a task queue.
 
-:parameter modules: An iterable over modules where to look for tests.
-    Alternatively it can be a callable returning the iterable over modules.
-    For example::
+    Each task is a group of test methods in a python TestCase class.
 
-        suite = TestSuite(modules=('regression',
-                                   ('examples','tests'),
-                                   ('apps','test_*')))
-        
-        def get_modules(suite):
-            ...
+    :parameter modules: An iterable over modules where to look for tests.
+        Alternatively it can be a callable returning the iterable over modules.
+        For example::
 
-        suite = TestSuite(modules=get_modules)
+            suite = TestSuite(modules=('regression',
+                                       ('examples','tests'),
+                                       ('apps','test_*')))
 
-    If not provided it is set as default to ``["tests"]`` which loads all
-    python module from the tests module in a recursive fashion.
-    Check the the :class:`TestLoader` for detailed information.
+            def get_modules(suite):
+                ...
 
-:parameter result_class: Optional class for collecting test results. By default
-    it used the standard ``unittest.TextTestResult``.
-:parameter plugins: Optional list of :class:`TestPlugin` instances.
-'''
+            suite = TestSuite(modules=get_modules)
+
+        If not provided it is set as default to ``["tests"]`` which loads all
+        python module from the tests module in a recursive fashion.
+        Check the the :class:`TestLoader` for detailed information.
+
+    :parameter result_class: Optional class for collecting test results.
+        By default it used the standard ``unittest.TextTestResult``.
+    :parameter plugins: Optional list of :class:`TestPlugin` instances.
+    '''
     name = 'test'
     cfg = pulsar.Config(apps=('tasks', 'test'),
                         loglevel='none',
                         task_paths=['pulsar.apps.test.case'],
                         plugins=())
+
     @local_property
     def runner(self):
-        '''Instance of :class:`TestRunner` driving the test case
-configuration and plugins.'''
-        if unittest is None:
-            raise ImportError('python %s requires unittest2 library for pulsar '
-                              'test suite application' % pyver)
-        if mock is None:
+        '''The :class:`TestRunner` driving the test case.'''
+        if unittest is None:    # pragma    nocover
+            raise ImportError('python %s requires unittest2 library for '
+                              'pulsar test suite application' % pyver)
+        if mock is None:    # pragma    nocover
             raise ImportError('python %s requires mock library for pulsar '
                               'test suite application' % pyver)
         result_class = getattr(self, 'result_class', None)
-        stream = get_stream(self.cfg)
+        stream = pulsar.get_stream(self.cfg)
         runner = TestRunner(self.cfg.plugins, stream, result_class)
         abort_message = runner.configure(self.cfg)
-        if abort_message:
+        if abort_message:    # pragma    nocover
             raise ExitTest(str(abort_message))
         return runner
 
@@ -449,28 +497,32 @@ configuration and plugins.'''
         if hasattr(modules, '__call__'):
             modules = modules(self)
         return TestLoader(self.root_dir, modules, runner, logger=self.logger)
-    
-    def on_config(self):
+
+    def on_config(self, arbiter):
         loader = self.loader
-        if self.cfg.list_labels:
+        stream = arbiter.stream
+        stream.writeln(sys.version)
+        if self.cfg.list_labels:    # pragma    nocover
             tags = self.cfg.labels
             if tags:
                 s = '' if len(tags) == 1 else 's'
-                print('\nTest labels for label{0} {1}\n'\
-                      .format(s,', '.join(tags)))
+                stream.writeln('\nTest labels for%s %s:' %
+                               (s, ', '.join(tags)))
             else:
-                print('\nAll test labels\n')
+                stream.writeln('\nAll test labels:')
+            stream.writeln('')
+
             def _tags():
                 for tag, mod in loader.testmodules(tags):
                     doc = mod.__doc__
                     if doc:
-                        tag = '{0} - {1}'.format(tag,doc)
+                        tag = '{0} - {1}'.format(tag, doc)
                     yield tag
             for tag in sorted(_tags()):
-                print(tag)
-            print('\n')
+                stream.writeln(tag)
+            stream.writeln('')
             return False
-    
+
     def monitor_start(self, monitor):
         '''When the monitor starts load all test classes into the queue'''
         super(TestSuite, self).monitor_start(monitor)
@@ -478,9 +530,10 @@ configuration and plugins.'''
         tags = self.cfg.labels
         exclude_tags = self.cfg.exclude_labels
         if self.cfg.show_leaks:
-            self.cfg.set('when_exit', show_leaks)
+            show = show_leaks if self.cfg.show_leaks == 1 else hide_leaks
+            self.cfg.set('when_exit', show)
             arbiter = pulsar.arbiter()
-            arbiter.cfg.set('when_exit', show_leaks)
+            arbiter.cfg.set('when_exit', show)
         try:
             self.local.tests = tests = []
             self.runner.on_start()
@@ -491,22 +544,28 @@ configuration and plugins.'''
             self._time_start = None
             if tests:
                 self.logger.info('loaded %s test classes', len(tests))
-                events.fire('tests', self, tests=tests)
+                self.fire_event('tests', tests=tests)
                 monitor.cfg.set('workers', min(self.cfg.workers, len(tests)))
                 self._time_start = default_timer()
                 for tag, testcls in self.local.tests:
                     self.backend.run('test', testcls, tag)
                 monitor.event_loop.call_repeatedly(1, self._check_queue)
-            else:
+            else:   # pragma    nocover
                 raise ExitTest('Could not find any tests.')
-        except ExitTest as e:
-            print(str(e))
+        except ExitTest as e:   # pragma    nocover
+            monitor.stream.writeln(str(e))
             monitor.arbiter.stop()
-        except Exception:
+        except Exception:   # pragma    nocover
             self.logger.critical('Error occurred before starting tests',
                                  exc_info=True)
             monitor.arbiter.stop()
 
+    @local_property
+    def events(self):
+        '''Events for the application: ``ready```, ``start``, ``stop``.'''
+        return EventHandler(one_time_events=('ready', 'start', 'stop'),
+                            many_times_events=('tests',))
+
     @classmethod
     def create_config(cls, *args, **kwargs):
         cfg = super(TestSuite, cls).create_config(*args, **kwargs)
@@ -515,9 +574,9 @@ configuration and plugins.'''
         for plugin in cfg.params['plugins']:
             cfg.settings.update(plugin.config.settings)
         return cfg
-    
+
     def _check_queue(self):
-        runner=  self.runner
+        runner = self.runner
         tests = yield self.backend.get_tasks(status=tasks.READY_STATES)
         if len(tests) == len(self.local.tests):
             self.logger.info('All tests have finished.')
@@ -532,4 +591,3 @@ configuration and plugins.'''
             else:
                 exit_code = 0
             raise pulsar.HaltServer(exit_code=exit_code)
-        
\ No newline at end of file
