@@ -30,27 +30,27 @@ class WrapTest(object):
     def __str__(self):
         return self.test._testMethodName
     __repr__ = __str__
-    
+
     @property
     def original_test(self):
         if isinstance(self.test, WrapTest):
             return self.test.original_test
         else:
             return self.test
-        
+
     def set_test_attribute(self, name, value):
         setattr(self.original_test, name, value)
-        
+
     def __getattr__(self, name):
         return getattr(self.original_test, name)
-        
+
     def _call(self):
         # This is the actual function to implement
         return self.testMethod()
-    
-    
+
+
 class TestPluginMeta(type):
-    
+
     def __new__(cls, name, bases, attrs):
         settings = {}
         for base in bases:
@@ -64,14 +64,15 @@ class TestPluginMeta(type):
         if not attrs.pop('virtual', False):
             setting_name = attrs.pop('name', name).lower()
             if setting_name:
-                def_flag = '--%s' % setting_name.replace(' ','-').replace('_','-')
+                def_flag = '--%s' % setting_name.replace(
+                    ' ', '-').replace('_', '-')
                 action = attrs.pop('action', None)
                 type = attrs.pop('type', None)
                 default = attrs.pop('default', None)
                 validator = attrs.pop('validator', None)
                 nargs = attrs.pop('nargs', None)
-                if validator is None and default is None and type is None\
-                    and nargs is None:
+                if (validator is None and default is None and type is None
+                        and nargs is None):
                     if action is None or action == 'store_true':
                         action = 'store_true'
                         default = False
@@ -80,26 +81,28 @@ class TestPluginMeta(type):
                         default = True
                         validator = pulsar.validate_bool
                 setting = pulsar.Setting(name=setting_name,
-                                    desc=attrs.pop('desc', name),
-                                    type=type,
-                                    flags=attrs.pop('flags', [def_flag]),
-                                    action=action,
-                                    default=default,
-                                    validator=validator,
-                                    nargs=nargs)
+                                         desc=attrs.pop('desc', name),
+                                         type=type,
+                                         flags=attrs.pop('flags', [def_flag]),
+                                         action=action,
+                                         default=default,
+                                         validator=validator,
+                                         nargs=nargs)
                 settings[setting.name] = as_test_setting(setting)
         attrs['config'] = pulsar.Config(settings=settings)
         return super(TestPluginMeta, cls).__new__(cls, name, bases, attrs)
-                
-    
-class TestPlugin(TestPluginMeta('TestPluginBase', (Plugin,), {'virtual': True})):
+
+
+class TestPlugin(TestPluginMeta('TestPluginBase',
+                                (Plugin,), {'virtual': True})):
     '''Base class for :class:`result.Plugin` which can be added to a
 :class:`TestSuite` to extend its functionalities. :ref:`Settings <settings>`
 can be specified as class attributes and collected into the
 :attr:`config` attribute.
 
 If the class attribute :attr:`name` is not specified or its value validate as
-``True``, an additional :ref:`setting <settings>` is added to the configuration.
+``True``, an additional :ref:`setting <settings>` is added to the
+configuration.
 In addition, a :class:`TestPlugin` can specify several additional
 :ref:`settings <settings>` as class attributes. For example, the
 :ref:`benchmark plugin <bench-plugin>` has an additional setting
@@ -115,22 +118,23 @@ for controlling the number of repetitions::
 
 .. attribute:: name
 
-    Class attribute used for adding the default plugin :ref:`setting <settings>`
+    Class attribute used for adding the default plugin
+    :ref:`setting <settings>`
     to the configuration container of the test suite application.
     If the attribute is not set, the class name in lower case is used.
     If set and validate as not ``True``, no new :ref:`setting <settings>`
     is added to the test suite configuration parameters. For example::
-    
+
         class MyPlugin(TestPlugin):
             name = None
-            
+
     won't add the default plugin :ref:`setting <settings>`.
-    
+
 .. attribute:: desc
 
     Class attribute used as the description of the :ref:`setting <settings>`.
     If :attr:`name` is disabled, this attribute is not relevant.
-    
+
 .. attribute:: config
 
     A :class:`pulsar.utils.config.Config` container created by th
@@ -139,12 +143,11 @@ for controlling the number of repetitions::
     as class attributes.
 '''
     virtual = True
-    
+
     def __new__(cls):
         o = super(TestPlugin, cls).__new__(cls)
         o.config = cls.config.copy()
         return o
-        
+
     def configure(self, cfg):
         self.config = cfg
-    
\ No newline at end of file
