@@ -10,11 +10,11 @@ __all__ = ['HttpTestClient']
 
 class DummyTransport(pulsar.Transport):
     '''A class simulating a :class:`pulsar.Transport` to a :attr:`connection`
-    
+
 .. attribute:: client
 
     The :class:`pulsar.Client` using this :class:`DummyTransport`
-    
+
 .. attribute:: connection
 
     The *server* connection for this :attr:`client`
@@ -22,16 +22,16 @@ class DummyTransport(pulsar.Transport):
     def __init__(self, client, connnection):
         self.client = client
         self.connection = connnection
-        
+
     def write(self, data):
         '''Writing data means calling ``data_received`` on the
 server :attr:`connection`.'''
         self.connection.data_received(data)
-        
+
     @property
     def address(self):
         return self.connection.address
-    
+
 
 class DummyConnectionPool(pulsar.ConnectionPool):
     '''A class for simulating a client connection with a server'''
@@ -45,8 +45,8 @@ class DummyConnectionPool(pulsar.ConnectionPool):
         client.connection_made(DummyTransport(producer, server))
         server.connection_made(DummyTransport(producer, client))
         return client
-        
-        
+
+
 class HttpTestClient(http.HttpClient):
     '''Useful :class:`pulsar.apps.http.HttpClient` for wsgi server
 handlers.
@@ -61,12 +61,13 @@ handlers.
     def __init__(self, test, wsgi_handler, **kwargs):
         self.test = test
         self.wsgi_handler = wsgi_handler
-        self.server_consumer = partial(HttpServerResponse, wsgi_handler, test.cfg)
+        self.server_consumer = partial(HttpServerResponse, wsgi_handler,
+                                       test.cfg)
         super(HttpTestClient, self).__init__(**kwargs)
-        
+
     def data_received(self, connnection, data):
         pass
-        
+
     def response(self, request):
         conn = self.get_connection(request)
         # build the protocol consumer
@@ -74,4 +75,3 @@ handlers.
         # start the request
         consumer.new_request(request)
         return consumer
-        
\ No newline at end of file
