@@ -8,7 +8,7 @@ SocketStreamTransport
 .. autoclass:: SocketStreamTransport
    :members:
    :member-order: bysource
-   
+
 TcpServer
 ============================
 
@@ -19,22 +19,33 @@ TcpServer
 import os
 import sys
 import socket
+from functools import partial
 
+from pulsar.utils.exceptions import PulsarException
 from pulsar.utils.internet import (TRY_WRITE_AGAIN, TRY_READ_AGAIN,
                                    ACCEPT_ERRORS, EWOULDBLOCK, EPERM,
                                    format_address, ssl_context, ssl,
-                                   WRITE_BUFFER_MAX_SIZE)
+                                   ESHUTDOWN, WRITE_BUFFER_MAX_SIZE)
 from pulsar.utils.structures import merge_prefix
 
 from .consts import NUMBER_ACCEPTS
-from .defer import multi_async, Deferred, Failure
+from .defer import multi_async, Deferred
 from .internet import SocketTransport, AF_INET6
 from .protocols import Server, logger
-    
+
+SSLV3_ALERT_CERTIFICATE_UNKNOWN = 1
+# Got this error on pypy
+SSL3_WRITE_PENDING = 1
+MAX_CONSECUTIVE_WRITES = 500
+
+
+class TooManyConsecutiveWrite(PulsarException):
+    '''Raise when too many consecutive writes are attempted.'''
+
 
 class SocketStreamTransport(SocketTransport):
     '''A :class:`pulsar.SocketTransport` for TCP streams.
-    
+
 The primary feature of a stream transport is sending bytes to a protocol
 and receiving bytes from the underlying protocol. Writing to the transport
 is done using the :meth:`write` and :meth:`writelines` methods.
@@ -42,13 +53,12 @@ The latter method is a performance optimisation, to allow software to take
 advantage of specific capabilities in some transport mechanisms.'''
     _paused_reading = False
     _paused_writing = False
-    SocketError = socket.error
-    
+
     def _do_handshake(self):
         self._event_loop.add_reader(self._sock_fd, self._ready_read)
         self._event_loop.call_soon(self._protocol.connection_made, self)
-        
-    def pause(self):
+
+    def pause(self):    # pragma    nocover
         """A :class:`SocketStreamTransport` can be paused and resumed.
 Invoking this method will cause the transport to buffer data coming
 from protocols but not sending it to the :attr:`protocol`. In other words,
@@ -57,7 +67,7 @@ until :meth:`resume` is called."""
         if not self._paused_reading:
             self._paused_reading = True
 
-    def resume(self):
+    def resume(self):    # pragma    nocover
         """Resume the receiving end. Data received will once again be
 passed to the :meth:`pulsar.Protocol.data_received` method."""
         if self._paused_reading:
@@ -66,8 +76,8 @@ passed to the :meth:`pulsar.Protocol.data_received` method."""
             self._read_buffer = []
             for chunk in buffer:
                 self._data_received(chunk)
-                
-    def pause_writing(self):
+
+    def pause_writing(self):    # pragma    nocover
         '''Suspend sending data to the network until a subsequent
 :meth:`resume_writing` call. Between :meth:`pause_writing` and
 :meth:`resume_writing` the transport's :meth:`write` method will just
@@ -76,45 +86,54 @@ be accumulating data in an internal buffer.'''
             self._paused_writing = True
             self._event_loop.remove_writer(self._sock_fd)
 
-    def resume_writing(self):
+    def resume_writing(self):    # pragma    nocover
         '''Restart sending data to the network.'''
         if self._paused_writing:
             if self._write_buffer:
                 self._event_loop.add_writer(self._sock_fd, self._write_ready)
             self._paused_writing = False
-            
+
     def write(self, data):
-        '''Write chunk of ``data`` to the endpoint.'''
+        '''Write chunk of ``data`` to the endpoint.
+        '''
         if not data:
             return
         self._check_closed()
-        writing = self.writing
+        is_writing = bool(self._write_buffer)
         if data:
+            # Add data to the buffer
             assert isinstance(data, bytes)
             if len(data) > WRITE_BUFFER_MAX_SIZE:
                 for i in range(0, len(data), WRITE_BUFFER_MAX_SIZE):
                     self._write_buffer.append(data[i:i+WRITE_BUFFER_MAX_SIZE])
             else:
                 self._write_buffer.append(data)
+        if self._paused_writing:
+            return
         # Try to write only when not waiting for write callbacks
-        if not writing and not self._paused_writing:
+        if not is_writing:
+            self._consecutive_writes = 0
             self._ready_write()
-            if self.writing:    # still writing
+            if self._write_buffer:    # still writing
                 self._event_loop.add_writer(self._sock_fd, self._ready_write)
             elif self._closing:
                 self._event_loop.call_soon(self._shutdown)
-                
+        else:
+            self._consecutive_writes += 1
+            if self._consecutive_writes > MAX_CONSECUTIVE_WRITES:
+                self.abort(TooManyConsecutiveWrite())
+
     def writelines(self, list_of_data):
         """Write a list (or any iterable) of data bytes to the transport."""
         for data in list_of_data:
             self.write(data)
-    
+
     def _write_continue(self, e):
         return e.args[0] in TRY_WRITE_AGAIN
-        
+
     def _read_continue(self, e):
         return e.args[0] == EWOULDBLOCK
-        
+
     def _ready_write(self):
         # Do the actual writing
         buffer = self._write_buffer
@@ -126,7 +145,7 @@ be accumulating data in an internal buffer.'''
         try:
             while buffer:
                 try:
-                    sent = self.sock.send(buffer[0])
+                    sent = self._sock.send(buffer[0])
                     if sent == 0:
                         break
                     merge_prefix(buffer, sent)
@@ -138,14 +157,16 @@ be accumulating data in an internal buffer.'''
                     else:
                         raise
         except Exception:
-            self.abort(Failure(sys.exc_info()))
+            failure = sys.exc_info()
         else:
-            if not self.writing:
+            if not self._write_buffer:
                 self._event_loop.remove_writer(self._sock_fd)
                 if self._closing:
                     self._event_loop.call_soon(self._shutdown)
             return tot_bytes
-    
+        if not self._closing:
+            self.abort(failure)
+
     def _ready_read(self):
         # Read from the socket until we get EWOULDBLOCK or equivalent.
         # If any other error occur, abort the connection and re-raise.
@@ -172,57 +193,75 @@ be accumulating data in an internal buffer.'''
                     finally:
                         self.close()
                 passes += 1
+            return
+        except self.SocketError:
+            failure = None if self._closing else sys.exc_info()
         except Exception:
-            self.abort(Failure(sys.exc_info()))
-    
-    
+            failure = sys.exc_info()
+        if failure:
+            self.abort(failure)
+
+    def mute_read_error(self, error):
+        '''Return ``True`` if a socket error from a read operation is muted.
+
+        This is when the socket cannot send sinse the socket has started
+        shutting down already.
+        '''
+        return error.errno in (ESHUTDOWN,)
+
+
 class SocketStreamSslTransport(SocketStreamTransport):
     SocketError = getattr(ssl, 'SSLError', None)
-    
+
     def __init__(self, event_loop, rawsock, protocol, sslcontext,
-                 server_side=True, **kwargs):
+                 server_side=True, server_hostname=None, **kwargs):
         sslcontext = ssl_context(sslcontext, server_side=server_side)
         sslsock = sslcontext.wrap_socket(rawsock, server_side=server_side,
-                                         do_handshake_on_connect=False)
+                                         do_handshake_on_connect=False,
+                                         server_hostname=server_hostname)
         self._rawsock = rawsock
+        # waiting for reading handshake
         self._handshake_reading = False
+        # waiting for writing handshake
         self._handshake_writing = False
         super(SocketStreamSslTransport, self).__init__(event_loop, sslsock,
                                                        protocol, **kwargs)
-    
+
+    @property
+    def rawsock(self):
+        '''The raw socket.
+
+        This is the socket not wrapped by the sslcontext.
+        '''
+        return self._rawsock
+
     def _write_continue(self, e):
-        return e.errno == ssl.SSL_ERROR_WANT_WRITE
-        
+        return e.errno in (ssl.SSL_ERROR_WANT_WRITE,
+                           SSL3_WRITE_PENDING)
+
     def _read_continue(self, e):
-        return e.errno == ssl.SSL_ERROR_WANT_READ
-    
+        return e.errno in (SSLV3_ALERT_CERTIFICATE_UNKNOWN,
+                           ssl.SSL_ERROR_WANT_READ)
+
     def _do_handshake(self):
         loop = self._event_loop
         try:
             self._sock.do_handshake()
         except self.SocketError as e:
             if self._read_continue(e):
-                self._handshake_reading = True
                 loop.remove_reader(self._sock_fd)
+                self._handshake_reading = True
                 loop.add_reader(self._sock_fd, self._do_handshake)
+                return
             elif self._write_continue(e):
-                self._handshake_writing = True
                 loop.remove_writer(self._sock_fd)
+                self._handshake_writing = True
                 loop.add_writer(self._sock_fd, self._do_handshake)
-            elif e.errno == ssl.SSL_ERROR_SSL:
-                try:
-                    peer = self._sock.getpeername()
-                except Exception:
-                    peer = '(not connected)'
-                failure = Failure(sys.exc_info())
-                failure.log(msg="SSL Error on fd %d %s: %s" % (
-                                                self._sock_fd, peer, e),
-                            log = self.logger, level='warning')
-                self.abort(failure)
+                return
             else:
-                self.abort(Failure(sys.exc_info()))
+                raise
         except Exception:
-            self.abort(Failure(sys.exc_info()))
+            failure = sys.exc_info()
         else:
             loop = self._event_loop
             if self._handshake_reading:
@@ -236,25 +275,27 @@ class SocketStreamSslTransport(SocketStreamTransport):
             self._handshake_reading = False
             self._handshake_writing = False
             self._event_loop.call_soon(self._protocol.connection_made, self)
+            return
+        self.abort(failure)
 
 
 class TcpServer(Server):
     '''A TCP :class:`pulsar.Server`.
-    
-.. attribute:: consumer_factory
 
-    Callable or a :class:`pulsar.ProtocolConsumer` class for producing
-    :class:`ProtocolConsumer` which handle the receiving, decoding and
-    sending of data.
-    
-'''
+    .. attribute:: consumer_factory
+
+        Callable or a :class:`pulsar.ProtocolConsumer` class for producing
+        :class:`ProtocolConsumer` which handle the receiving, decoding and
+        sending of data.
+
+    '''
     def start_serving(self, backlog=100, sslcontext=None):
         '''Start serving the Tcp socket.
-        
-:parameter backlog: Number of maximum connections
-:parameter sslcontext: optional SSLContext object.
-:return: a :class:`pulsar.Deferred` called back when the server is serving
-    the socket.'''
+
+        :param backlog: Number of maximum connections
+        :param sslcontext: optional SSLContext object.
+        :return: a :class:`pulsar.Deferred` called back when the server is
+            serving the socket.'''
         if not self.event('start').done():
             res = self._event_loop.start_serving(self.protocol_factory,
                                                  host=self._host,
@@ -262,40 +303,40 @@ class TcpServer(Server):
                                                  sock=self._sock,
                                                  backlog=backlog,
                                                  ssl=sslcontext)
-            return res.add_callback(self._got_sockets)\
-                      .add_both(lambda r: self.fire_event('start', r))
-    
+            return res.add_callback(self._got_sockets
+                                    ).add_both(partial(self.fire_event,
+                                                       'start'))
+
     def stop_serving(self):
         '''Stop serving the :class:`pulsar.Server.sock`'''
         if self._sock:
             sock, self._sock = self._sock, None
-            self._event_loop.call_now_threadsafe(self._stop_serving, sock)
-    
+            self._event_loop.call_soon_threadsafe(self._stop_serving, sock)
+
     def close(self):
         '''Same as :meth:`stop_serving` method.'''
         self.stop_serving()
-            
+
     def _got_sockets(self, sockets):
         self._sock = sockets[0]
         self.logger.info('%s serving on %s', self._name,
                          format_address(self.address))
         return self
-    
+
     def _stop_serving(self, sock):
         self._event_loop.stop_serving(sock)
         self.fire_event('stop')
-    
-    
+
+
 def create_connection(event_loop, protocol_factory, host, port, ssl,
                       family, proto, flags, sock, local_addr):
     if host is not None or port is not None:
         if sock is not None:
             raise ValueError(
                 'host/port and sock can not be specified at the same time')
-
-        fs = [event_loop.getaddrinfo(
-                host, port, family=family,
-                type=socket.SOCK_STREAM, proto=proto, flags=flags)]
+        fs = [event_loop.getaddrinfo(host, port, family=family,
+                                     type=socket.SOCK_STREAM, proto=proto,
+                                     flags=flags)]
         if local_addr is not None:
             fs.append(event_loop.getaddrinfo(
                 *local_addr, family=family,
@@ -364,7 +405,8 @@ def create_connection(event_loop, protocol_factory, host, port, ssl,
     else:
         transport = SocketStreamTransport(event_loop, sock, protocol)
     yield transport, protocol
-    
+
+
 def start_serving(event_loop, protocol_factory, host, port, ssl,
                   family, flags, sock, backlog, reuse_address):
     #Coroutine which starts socket servers
@@ -424,6 +466,7 @@ def start_serving(event_loop, protocol_factory, host, port, ssl,
                               event_loop, protocol_factory, sock, ssl)
     yield sockets
 
+
 def sock_connect(event_loop, sock, address, future=None):
     fd = sock.fileno()
     connect = False
@@ -440,8 +483,8 @@ def sock_connect(event_loop, sock, address, future=None):
                 sock.connect(address)
             except socket.error as e:
                 if e.args[0] in TRY_WRITE_AGAIN:
-                    event_loop.add_connector(fd, sock_connect, event_loop, sock,
-                                             address, future)
+                    event_loop.add_connector(fd, sock_connect, event_loop,
+                                             sock, address, future)
                     return future
                 else:
                     raise
@@ -456,8 +499,11 @@ def sock_connect(event_loop, sock, address, future=None):
             future.callback(None)
     except Exception as exc:
         return future.callback(exc)
-        
-def sock_accept(event_loop, sock, future=None):
+
+
+def sock_accept(event_loop, sock, future=None):    # pragma    nocover
+    #TODO
+    #do we need this function?
     fd = sock.fileno()
     if future is None:
         future = Deferred()
@@ -470,7 +516,8 @@ def sock_accept(event_loop, sock, future=None):
             future.set_result((conn, address))
         except socket.error as e:
             if e.args[0] in TRY_READ_AGAIN:
-                event_loop.add_reader(fd, sock_accept, event_loop, sock, future)
+                event_loop.add_reader(fd, sock_accept, event_loop, sock,
+                                      future)
             elif e.args[0] == EPERM:
                 # Netfilter on Linux may have rejected the
                 # connection, but we get told to try to accept() anyway.
@@ -481,7 +528,9 @@ def sock_accept(event_loop, sock, future=None):
             future.callback(e)
     return future
 
+
 def sock_accept_connection(event_loop, protocol_factory, sock, ssl):
+    '''Used by start_serving.'''
     try:
         for i in range(NUMBER_ACCEPTS):
             try:
@@ -505,4 +554,4 @@ def sock_accept_connection(event_loop, protocol_factory, sock, ssl):
                 SocketStreamTransport(event_loop, conn, protocol,
                                       extra={'addr': address})
     except Exception:
-        logger(event_loop).exception('Could not accept new connection')
\ No newline at end of file
+        logger(event_loop).exception('Could not accept new connection')
